# XAgents

XAgent项目提供快速构建、验证、接入Agent的能力提供。提供的能力有：

- 不同平台的大模型对话
- 知识库的管理
- RAG的能力
- 工具调用的能力

接入方式包括：

- pythonSDK（python程序快速接入，开发中)
- http service (用http请求的方式接入)
- Web Demo（基于Streamlit快速搭建一个web页面，直接上手使用、演示)
- ### install

  基于python3.10或更高版本

  `pip install -r requirements.txt`
